#
# spec file for package joda-time
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define tzversion tzdata2010h
Name:           joda-time
Version:        1.6
Release:        23.17
Summary:        Java date and time API
License:        Apache-2.0
Group:          Development/Libraries
Url:            http://joda-time.sourceforge.net/index.html
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}-src.tar.gz
Source1:        ftp://elsie.nci.nih.gov/pub/%{tzversion}.tar.gz
Patch0:         joda-time-use-system-junit.patch
BuildRequires:  ant
BuildRequires:  java-devel > 1.5.0
BuildRequires:  javapackages-tools
BuildRequires:  junit
Requires:       java > 1.5.0
Requires:       javapackages-tools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Joda-Time provides a quality replacement for the Java date
and time classes. The design allows for multiple calendar
systems, while still providing a simple API. The 'default'
calendar is the ISO8601 standard which is used by XML. The
Gregorian, Julian, Buddhist, Coptic and Ethiopic systems
are also included, and we welcome further additions.
Supporting classes include time zone, duration, format
and parsing.

%package        javadoc
Summary:        Javadocs for %{name}
Group:          Documentation
Requires:       %{name} = %{version}-%{release}
Requires:       javapackages-tools

%description    javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n %{name}-%{version}-src
%patch0 -p1

# all java binaries must be removed from the sources
find . -name '*.jar' -exec rm -f '{}' \;
find . -name '*.class' -exec rm -f '{}' \;

# prove that these binaries aren't used in building joda-time
rm -rf src/testdata/

# replace internal tzdata
rm -f src/java/org/joda/time/tz/src/*
tar -xzf %{SOURCE1} -C src/java/org/joda/time/tz/src/

%build
ant
ant javadoc

%install
# jars
install -d -m 755 %{buildroot}%{_javadir}
# Don't install a versioned jar and symlink to it, instead install
# the unversioned jar as per Java Packaging Guidelines
install -m 644 build/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar

# javadocs
install -p -d -m 755 %{buildroot}%{_javadocdir}/%{name}
cp -a build/docs/* %{buildroot}%{_javadocdir}/%{name}

%files
%defattr(-,root,root,-)
%doc LICENSE.txt RELEASE-NOTES.txt ToDo.txt
%{_javadir}/%{name}.jar

%files javadoc
%defattr(-,root,root,-)
%doc %{_javadocdir}/%{name}

%changelog
* Tue Jul  8 2014 tchvatal@suse.com
- Do not depend on ant-nodeps.
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Wed Apr 28 2010 ro@suse.de
- update timezone data to current 2010h
* Wed Apr 28 2010 ro@suse.de
- remove needless buildroot cleaning st start of install section
* Thu Jul 23 2009 rel-eng@lists.fedoraproject.org
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild
* Tue Feb 24 2009 rel-eng@lists.fedoraproject.org
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild
* Thu Dec 11 2008 konrad@tylerc.org
- New upstream version (1.6).
* Thu Oct 30 2008 konrad@tylerc.org
- New tzdata.
* Sun Oct 12 2008 konrad@tylerc.org
- New tzdata (2008g).
* Fri Aug 22 2008 konrad@tylerc.org
- New version with new tzdata (2008e).
* Fri Jul 18 2008 konrad@tylerc.org
- New version with new tzdata (2008d).
* Sun Jun  8 2008 konrad@tylerc.org
- New version with new tzdata (2008c).
* Sat Apr  5 2008 konrad@tylerc.org
- Don't compile GCJ bits yet as we hit some GCJ bug.
* Fri Apr  4 2008 konrad@tylerc.org
- Update to tzdata2008b.
- Use unversioned jar.
- Some small things to comply with Java Packaging Guidelines.
- GCJ support.
* Sun Mar 16 2008 konrad@tylerc.org
- Many small changes from bz# 436239 comment 6.
- Change -javadocs to -javadoc in accordance with java packaging
  guidelines draft.
* Sat Mar 15 2008 konrad@tylerc.org
- Use system junit via Mamoru Tasaka's patch.
* Sun Mar  2 2008 konrad@tylerc.org
- Initial package.
